"""empty message

Revision ID: ac10bf3f974c
Revises: ('c8735fa14a0a', '7a8c4aa92678')
Create Date: 2018-11-06 08:27:37.278677
"""

# revision identifiers, used by Alembic.
revision = "ac10bf3f974c"
down_revision = ("c8735fa14a0a", "7a8c4aa92678")


def upgrade():
    """Upgrade"""
    pass


def downgrade():
    """Downgrade"""
    pass
